import java.util.HashMap;

/**
 * An interface for a SpacePort that can hold arriving and departing SpaceShips.
 * 
 * @author Joel Ross
 * @version Sp14
 */
public interface SpacePort
{
	/**
	 * Docks a ship registered with the given "key" in the SpacePort. 
	 * If a SpaceShip with the same key already exists, this method should NOT add in the new ship and return false.
	 * @param key The "key" used to register the SpaceShip with.
	 * @param value The SpaceShip to be docked.
	 * @return whether the ship was successfully added.
	 */
	public boolean dock(String key, SpaceShip value);


    /** 
     * Removes the ship with the given key from the SpacePort (e.g., if it departs).
	 * @param key The "key" used to register the SpaceShip
	 * @return The SpaceShip that has left the SpacePort, or null if no such SpaceShip existed
	 */
	public SpaceShip remove(String key);

	
	/**
	 * Accesses the SpaceShip registered with the given "key", so that it can be inspected by Imperial Authorities (for example)
	 * @param key The "key" used to register the SpaceShip
	 * @return The SpaceShip that is registered with that key (will be null if no such ship exists)
	 */
	public SpaceShip access(String key);
    
	
	/**
	 * Returns a HashMap containing statistics about the usage of this SpacePort. 
	 * Each statistics should be keyed to a SpacePortSimulation.Statistic enumerated type, and given in integer precision
	 * Statistics should include:
	 *  1. Current # of ships docked
	 *  2. Maximum # of ships docked
	 *  3. Current # of berths
	 *  4. Average # collisions for successful ship locating (includes docking, removing, and accessing) [round up]
	 *  5. Maximum # collisions for successful ship locating (includes docking, removing, and accessing)
	 *  6. Average # collisions for unsuccessful ship locating (includes removing, and accessing)  [round up]
	 *  7. Maximum # collisions for unsuccessful ship locating (includes removing, and accessing)
	 *  8. Average # collisions for all ship locating (includes docking, removing, and accessing)  [round up]
	 *  9. Maximum # collisions for all ship locating (includes docking, removing, and accessing)
	 * @return A HashMap of the statistics
	 */
	public HashMap<SpacePortSimulation.Statistic, Integer> getStatistics();
	
}
